@@ -27,7 +27,7 @@ and show how to use the API.
 =head1 Synopsis
 
   use Term::ReadLine::Perl5;
-  $term = new Term::ReadLine::Perl5 'ProgramName';
+  $term = Term::ReadLine::Perl5->new('ProgramName');
   while ( defined ($_ = $term->readline('prompt>')) ) {
     ...
   }
@@ -37,7 +37,7 @@ use warnings; use strict;
 use Term::ReadLine::Perl5::readline;
 no warnings 'once';
 
-our $VERSION = '1.41';
+our $VERSION = '1.42';
 
 use Carp;
 eval "use rlib '.' ";  # rlib is now optional
@@ -62,7 +62,7 @@ conventions with the leading C<rl_> stripped.
 
 Example:
 
-    $term = new Term::ReadLine::Perl5 'ReadLineTest'
+    $term = Term::ReadLine::Perl5->new('ReadLineTest');
     $attribs = $term->Attribs;
     $v = $attribs->{history_base};	# history_base
 
@@ -107,7 +107,7 @@ L<Term::ReadLine>.
 
 =head3 C<ReadLine>
 
-    Readline() -> 'Term::ReadLine::Perl5
+    Readline() -> 'Term::ReadLine::Perl5'
 
 returns the actual package that executes the commands. If this package
 is used, the value is C<Term::ReadLine::Perl5>.
@@ -399,10 +399,12 @@ programmers will use.
 L<Term::ReadLine::Perl5::readline-guide> is guide to the guts of the
 non-OO portion of L<Term::ReadLine::Perl5>
 
-=item * L<Term::ReadLine::Perl5::History> describes the history
+=item *
+
+L<Term::ReadLine::Perl5::History> describes the history
 mechanism
 
-item *
+=item *
 
 L<Term::ReadLine> is a generic package which can be used to
 select this among other compatible GNU Readline packages.
